==> blobAndConquer-0.5-1.tar.gz: blobAndConquer-0.5/src/main.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "headers.h"

extern void initSystem();
extern void initOpenGL();
extern void cleanup();

extern void loadLocaleIndex();
extern void loadAllDefinitions();

extern void loadGameData(int slot);
extern void saveGameData(int slot);
extern void createTestData();

extern void loadTextures();
extern void loadRawModels();

extern void loadCampaignCountries();
extern void loadMission(char *mission);
extern void loadMissionOrSave(char *mission);
extern void setupMission();

extern void doPreBattlePlayerSetup();
extern void newGame();
extern int mainBattleLoop();
extern int doWorldMap();
extern void doDebriefing();

extern void removeUnneededResources();

extern int doTitle();
extern int doGameOver();

extern void openGLTest();

extern bool doMasterMindPuzzle(int seed);
extern bool doLaserGridPuzzle(int seed);
extern void loadWidgets(char *filename);

// initialise all singletons
Audio *audio = Audio::getInstance();
BSP *bsp = BSP::getInstance();
BoundingBoxManager *bbManager = BoundingBoxManager::getInstance();
Engine *engine = Engine::getInstance();
EntityManager *entityManager = EntityManager::getInstance();
Game *game = Game::getInstance();
Graphics *graphics = Graphics::getInstance();
LocaleManager *localeManager = LocaleManager::getInstance();
Map *map = Map::getInstance();
Mission *mission = Mission::getInstance();
ModelManager *modelManager = ModelManager::getInstance();
Mouse *mouse = Mouse::getInstance();
Pak *pak = Pak::getInstance();
ParticleManager *particleManager = ParticleManager::getInstance();
RandomNameGenerator *randomNameGenerator = RandomNameGenerator::getInstance();
TextureManager *textureManager = TextureManager::getInstance();
TextureSpecManager *textureSpecManager = TextureSpecManager::getInstance();
Trace *tracer = new Trace();
UIManager *uiManager = UIManager::getInstance();

Camera *camera = Camera::getInstance();
Unit *player = NULL;
Entity *self = NULL;

==> blobAndConquer-0.8-2.tar.gz: blobAndConquer-0.8/src/main.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "headers.h"

extern void initSystem();
extern void initOpenGL();
extern void cleanup();

extern void loadLocaleIndex();
extern void loadAllDefinitions();

extern void loadGameData(int slot, bool restart);
extern void saveGameData(int slot);
extern void createTestData();

extern void loadTextures();
extern void loadRawModels();

extern void loadCampaignCountries();
extern void loadMission(char *mission);
extern void loadMissionOrSave(char *mission);
extern void setupMission();

extern void doPreBattlePlayerSetup();
extern void newGame();
extern int mainBattleLoop();
extern int doWorldMap();
extern void doDebriefing();

extern void removeUnneededResources();
extern void initCutsceneInstructions();

extern int doTitle();
extern int doGameOver();

extern void openGLTest();

extern bool doMasterMindPuzzle(int seed);
extern bool doLaserGridPuzzle(int seed);
extern void loadWidgets(char *filename);

// initialise all singletons
Audio *audio = Audio::getInstance();
BSP *bsp = BSP::getInstance();
BoundingBoxManager *bbManager = BoundingBoxManager::getInstance();
Engine *engine = Engine::getInstance();
EntityManager *entityManager = EntityManager::getInstance();
Game *game = Game::getInstance();
Graphics *graphics = Graphics::getInstance();
LocaleManager *localeManager = LocaleManager::getInstance();
Map *map = Map::getInstance();
Mission *mission = Mission::getInstance();
ModelManager *modelManager = ModelManager::getInstance();
Mouse *mouse = Mouse::getInstance();
Pak *pak = Pak::getInstance();
ParticleManager *particleManager = ParticleManager::getInstance();
RandomNameGenerator *randomNameGenerator = RandomNameGenerator::getInstance();
TextureManager *textureManager = TextureManager::getInstance();
TextureSpecManager *textureSpecManager = TextureSpecManager::getInstance();
Trace *tracer = new Trace();
UIManager *uiManager = UIManager::getInstance();

Camera *camera = Camera::getInstance();
Unit *player = NULL;
Entity *self = NULL;
